﻿using System;
using System.Drawing;

using Foundation;
using UIKit;
using Syncfusion.SfChart.iOS;
using CoreGraphics;

namespace ChartSample
{
	public partial class ChartSampleViewController : UIViewController
	{
		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public ChartSampleViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			SFChart chart        		= new SFChart ();
			chart.EdgeInsets			= new UIEdgeInsets (20,10,10,10);
			chart.Frame              	= new CGRect (0, 10, this.View.Frame.Width, this.View.Frame.Height / 2+120);
			;

			ChartDataModel dataModel 	= new ChartDataModel ();
			chart.DataSource         	= dataModel as SFChartDataSource;

			UITableView	table = new UITableView ();
			table.Frame = new CGRect (0, this.View.Frame.Height / 2+120, this.View.Frame.Width, this.View.Frame.Height / 2);
			table.DataSource = new TableDataSource (dataModel.DataPoints,dataModel.IconColors);

			this.View.AddSubview (chart);
			this.View.AddSubview (table);
		}

	}
		
	public class ChartDataModel : SFChartDataSource
	{
		public NSMutableArray DataPoints {
			get;
			set;
		} 

		public NSArray IconColors{
			get;
			set;
		}

		public ChartDataModel ()
		{
			DataPoints     = new NSMutableArray ();
			AddDataPointsForChart ("Hair", 32);
			AddDataPointsForChart ("Nails", 63);
			AddDataPointsForChart ("Spa", 32);
			AddDataPointsForChart ("Massage", 63);
	
			NSObject[] cusColors = new NSObject[] {UIColor.FromRGB(133,185,229),UIColor.FromRGB(144,155,201),UIColor.FromRGB(183,116,192),UIColor.FromRGB(244,143,177)};
			IconColors	= NSArray.FromNSObjects(cusColors);
		}
			
		void AddDataPointsForChart (string xValue,Double yValue)
		{
			DataPoints.Add (new SFChartDataPoint (NSObject.FromObject (xValue), NSObject.FromObject (yValue)));
		}
			
		public override nint NumberOfSeriesInChart (SFChart chart)
		{
			return 1;
		}
			
		public override SFSeries GetSeries (SFChart chart, nint index)
		{
			SFDoughnutSeries series 		= new SFDoughnutSeries ();
			series.DataMarkerPosition	= SFChartCircularSeriesLabelPosition.OutsideExtended;
			series.StartAngle 				= 90;
			series.ColorModel.Palette 		= SFChartColorPalette.Custom;
			series.CircularCoefficient 		= (float)0.7;
			series.DoughnutCoefficient 		= (float)0.6;
			series.ColorModel.CustomColors	= IconColors;
			series.DataMarker.ShowLabel		= true;
			series.DataMarker.LabelContent	= SFChartLabelContent.Percentage;
			return series;
		}
			
		public override SFChartDataPoint GetDataPoint (SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint> ((nuint)index);
		}
			
		public override nint GetNumberOfDataPoints (SFChart chart, nint index)
		{
			return (int)DataPoints.Count;
		}
	}
		
}

