﻿using System;
using UIKit;
using Foundation;
using CoreGraphics;
using Syncfusion.SfChart.iOS;
using CoreAnimation;

namespace ChartSample
{
	public class TableDataSource:UITableViewDataSource
	{
		nuint index;

		public NSMutableArray DataPoints {
			get;
			set;
		}

		public NSArray IConColors{
			get;
			set;
		}

		public TableDataSource(NSMutableArray dataPoints, NSArray iconColors)
		{
			IConColors = iconColors;
			DataPoints = dataPoints;
			index = 0;
		}

		public override nint NumberOfSections (UITableView tableView)
		{
			return 1;
		}

		public override nint RowsInSection (UITableView tableview, nint section)
		{
			return (nint) DataPoints.Count;
		}

		public override UITableViewCell GetCell (UITableView tableView, NSIndexPath indexPath)
		{
			var cell = tableView.DequeueReusableCell (CustomViewCell.Key) as CustomViewCell;

			if (cell == null)
				cell = new CustomViewCell ();
			
			nuint row = (nuint)indexPath.Row;
			SFChartDataPoint data = DataPoints.GetItem<SFChartDataPoint> ((nuint)row);

			cell.LegendIcon.IconColor = IConColors.GetItem<UIColor>((nuint)index).CGColor;
			cell.TextLabel.Text = data.XValue.ToString();
			cell.DetailTextLabel.Text = "$" + data.YValue.ToString ();
			cell.DetailTextLabel.TextColor 	= UIColor.FromRGB(244,143,177);

			cell.Accessory = UITableViewCellAccessory.None;
			cell.SelectionStyle = UITableViewCellSelectionStyle.None;

			index++;
			index = index >= IConColors.Count ? 0 :index;

			return cell;
		}
			
	}

	public class IconLayer: CALayer
	{

		public CGColor IconColor {
			get;
			set;
		}

		public IconLayer()
		{

		}

		public override void DrawInContext (CGContext ctx)
		{
			ctx.SaveState ();
			ctx.SetStrokeColor (this.BorderColor);
			ctx.SetLineWidth ((nfloat)this.BorderWidth);
			ctx.SetFillColor (IconColor);
			ctx.AddEllipseInRect (new CGRect( this.Frame.X+10,this.Frame.Height/2-20/2,20,20));
			ctx.DrawPath (CGPathDrawingMode.FillStroke);
			ctx.RestoreState ();

		}
	}

	public class CustomViewCell : UITableViewCell
	{
		public static readonly NSString Key = new NSString ("CustomViewCell");

		public IconLayer LegendIcon {
			get;
			set;
		}

		public CustomViewCell () : base (UITableViewCellStyle.Value1, Key)
		{
			this.LegendIcon  = new IconLayer ();
			this.Layer.AddSublayer (LegendIcon);
			LegendIcon.SetNeedsDisplay ();
		}

		public override void LayoutSubviews ()
		{
			base.LayoutSubviews ();

			NSString labelString 	= (NSString) this.TextLabel.Text ;
			if (labelString != null) 
			{
				this.LegendIcon.Frame = new CGRect (this.Frame.X+5 , 0, 50, 50);
				this.TextLabel.Frame = new CGRect (this.LegendIcon.Frame.Size.Width, 0, 100, 49);
				this.DetailTextLabel.Font 	= UIFont.FromName ("Helvetica", 25f);
				this.DetailTextLabel.Frame 	= new CGRect (this.Frame.Width-80f, 10f, 49.5f, 30f);
				this.DetailTextLabel.TextAlignment = UITextAlignment.Right;

				if (UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Pad) {
					this.DetailTextLabel.Frame = new CGRect (this.Frame.Width-80f, 10, 49.5f, 30f);
				}
			}
		}


	}

}

